@@ -4,7 +4,7 @@
 using namespace arma;
 
 // [[Rcpp::export(.PLR_loss_cpp)]]
-double PLR_loss_cpp(arma::mat X, arma::vec y, arma::vec pi, arma::vec theta, double h, double gamma)
+double PLR_loss_cpp(arma::mat X, arma::vec y, arma::vec pi, arma::vec theta, double h, double gamma, int kernel)
 {
   int i, j;
   int k;
@@ -20,7 +20,8 @@ double PLR_loss_cpp(arma::mat X, arma::vec y, arma::vec pi, arma::vec theta, dou
     for (j=0; j<i; j++)
     {
       u = (index(i)-index(j))/h;
-      if (u > -1 && u < 1) sum =  sum + 1.0* pi(i)*pi(j)*(y(i)-y(j)) * (9.0/8.0*u - 5.0/8.0*pow(u,3.0) + 0.5);
+      if (u > -1 && u < 1 && kernel == 1) sum =  sum + 1.0* pi(i)*pi(j)*(y(i)-y(j)) * (9.0/8.0*u - 5.0/8.0*pow(u,3.0) + 0.5);
+      if (u > -1 && u < 1 && kernel == 2) sum =  sum + 1.0* pi(i)*pi(j)*(y(i)-y(j)) * (45.0/32.0*u - 25.0/16.0*pow(u,3.0) + 21.0/32.0*pow(u,5.0) + 0.5);
       if (u >= 1) sum =  sum + 1.0* pi(i)*pi(j)*(y(i)-y(j));
     }
   }
